<?php
/**
 * Sample implementation of the Custom Header feature
 * http://codex.wordpress.org/Custom_Headers
 *
 * You can add an optional custom header image to header.php like so ...
 * <?php if ( get_header_image() ) : ?>
 * <a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
 * <img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="">
 * </a>
 * <?php endif; // End header image check. ?>
 *
 * @package BOXY
 */

/**
 * Setup the WordPress core custom header feature.
 *
 * @uses boxy_header_style()
 * @uses boxy_admin_header_style()
 * @uses boxy_admin_header_image()
 *
 * @package BOXY
 */
function boxy_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'boxy_custom_header_args', array(
				'default-image'          => '',
				'default-text-color'     => '000000',
				'width'                  => 1600,
				'height'                 => 100,
				'flex-height'            => true,
				'wp-head-callback'       => 'boxy_header_style',
				'admin-head-callback'    => 'boxy_admin_header_style',
				'admin-preview-callback' => 'boxy_admin_header_image',
			) ) );
}
add_action( 'after_setup_theme', 'boxy_custom_header_setup' );

if ( ! function_exists( 'boxy_header_style' ) ) :
	/**
	 * Styles the header image and text displayed on the blog
	 *
	 * @see boxy_custom_header_setup().
	 */
	function boxy_header_style() {
		$header_text_color = get_header_textcolor();
		// If we get this far, we have custom styles. Let's do this.

		if ( get_header_image() ) { ?>
			<style type="text/css">    
				.logo-wrapper  {
					background-image: url(<?php echo get_header_image(); ?>);
					display: block;
				}
		        .header-inner {
		        	
		        }
			</style><?php
		}

		// If no custom options for text are set, let's bail
		// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
		if ( HEADER_TEXTCOLOR == $header_text_color ) {
			return;
		}
	}
endif; // boxy_header_style

if ( ! function_exists( 'boxy_admin_header_style' ) ) :
	/**
	 * Styles the header image displayed on the Appearance > Header admin panel.
	 *
	 * @see boxy_custom_header_setup().
	 */
	function boxy_admin_header_style() {
?>
	<style type="text/css">
		.appearance_page_custom-header #headimg {
			border: none;
		}
		#headimg h1,
		#desc {
		}
		#headimg h1 {
		}
		#headimg h1 a {
		}
		#desc {
		}
		#headimg img {
		}
	</style>
<?php
	}
endif; // boxy_admin_header_style

if ( ! function_exists( 'boxy_admin_header_image' ) ) :
	/**
	 * Custom header image markup displayed on the Appearance > Header admin panel.
	 *
	 * @see boxy_custom_header_setup().
	 */
	function boxy_admin_header_image() {
		$style = sprintf( ' style="color:#%s;"', get_header_textcolor() );
?>
	<div id="headimg">
		<h1 class="displaying-header-text"><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div class="displaying-header-text" id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
		<?php if ( get_header_image() ) : ?>
		<img src="<?php header_image(); ?>" alt="">
		<?php endif; ?>
	</div>
<?php
	}
endif; // boxy_admin_header_image
